summaryrefslogtreecommitdiff
path: root/dvbdevice.c
diff options
context:
space:
mode:
authorKlaus Schmidinger <vdr@tvdr.de>2003-04-26 11:58:54 +0200
committerKlaus Schmidinger <vdr@tvdr.de>2003-04-26 11:58:54 +0200
commitfd0774c811fca36db9cc1200037e8e8ee2608bb8 (patch)
tree0db5d193d8ce0d2e3dd4b86509ccac416b6d5ebd /dvbdevice.c
parentf53912de1e265edbf166eac640b5509b0fd25356 (diff)
downloadvdr-fd0774c811fca36db9cc1200037e8e8ee2608bb8.tar.gz
vdr-fd0774c811fca36db9cc1200037e8e8ee2608bb8.tar.bz2
The PCR PID can now be set separately from the video PID
Diffstat (limited to 'dvbdevice.c')
-rw-r--r--dvbdevice.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/dvbdevice.c b/dvbdevice.c
index c25ebef4..32c5b9e6 100644
--- a/dvbdevice.c
+++ b/dvbdevice.c
@@ -4,7 +4,7 @@
* See the main source file 'vdr.c' for copyright information and
* how to reach the author.
*
- * $Id: dvbdevice.c 1.54 2003/04/19 14:24:25 kls Exp $
+ * $Id: dvbdevice.c 1.55 2003/04/26 11:49:06 kls Exp $
*/
#include "dvbdevice.h"
@@ -524,8 +524,8 @@ void cDvbDevice::SetVideoFormat(bool VideoFormat16_9)
CHECK(ioctl(fd_video, VIDEO_SET_FORMAT, VideoFormat16_9 ? VIDEO_FORMAT_16_9 : VIDEO_FORMAT_4_3));
}
-// ptAudio ptVideo ptTeletext ptDolby ptOther
-dmx_pes_type_t PesTypes[] = { DMX_PES_AUDIO, DMX_PES_VIDEO, DMX_PES_TELETEXT, DMX_PES_OTHER, DMX_PES_OTHER };
+// ptAudio ptVideo ptPcr ptTeletext ptDolby ptOther
+dmx_pes_type_t PesTypes[] = { DMX_PES_AUDIO, DMX_PES_VIDEO, DMX_PES_PCR, DMX_PES_TELETEXT, DMX_PES_OTHER, DMX_PES_OTHER };
bool cDvbDevice::SetPid(cPidHandle *Handle, int Type, bool On)
{
@@ -662,6 +662,7 @@ bool cDvbDevice::SetChannelDevice(const cChannel *Channel, bool LiveView)
DelPid(pidHandles[ptAudio].pid);
DelPid(pidHandles[ptVideo].pid);
+ DelPid(pidHandles[ptPcr].pid);
DelPid(pidHandles[ptTeletext].pid);
DelPid(pidHandles[ptDolby].pid);
}
@@ -683,7 +684,7 @@ bool cDvbDevice::SetChannelDevice(const cChannel *Channel, bool LiveView)
if (TurnOnLivePIDs) {
aPid1 = Channel->Apid1();
aPid2 = Channel->Apid2();
- if (!(AddPid(Channel->Apid1(), ptAudio) && AddPid(Channel->Vpid(), ptVideo))) {//XXX+ dolby dpid1!!! (if audio plugins are attached)
+ if (!(AddPid(Channel->Ppid(), ptPcr) && AddPid(Channel->Apid1(), ptAudio) && AddPid(Channel->Vpid(), ptVideo))) {//XXX+ dolby dpid1!!! (if audio plugins are attached)
esyslog("ERROR: failed to set PIDs for channel %d on device %d", Channel->Number(), CardIndex() + 1);
return false;
}